@@ -5,9 +5,9 @@ use strict;
 use warnings;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2022-09-30'; # DATE
+our $DATE = '2023-01-20'; # DATE
 our $DIST = 'App-SahUtils'; # DIST
-our $VERSION = '0.482'; # VERSION
+our $VERSION = '0.483'; # VERSION
 
 our %SPEC;
 
@@ -348,7 +348,7 @@ App::SahUtils - Collection of CLI utilities for Sah and Data::Sah
 
 =head1 VERSION
 
-This document describes version 0.482 of App::SahUtils (from Perl distribution App-SahUtils), released on 2022-09-30.
+This document describes version 0.483 of App::SahUtils (from Perl distribution App-SahUtils), released on 2023-01-20.
 
 =head1 SYNOPSIS
 
@@ -365,6 +365,8 @@ L<Sah> and L<Data::Sah>:
 
 =item * L<get-sah-type>
 
+=item * L<get-value-with-sah>
+
 =item * L<is-sah-builtin-type>
 
 =item * L<is-sah-collection-builtin-type>
@@ -401,6 +403,8 @@ L<Sah> and L<Data::Sah>:
 
 =item * L<list-sah-type-modules>
 
+=item * L<list-sah-value-rule-modules>
+
 =item * L<normalize-sah-schema>
 
 =item * L<resolve-sah-schema>
@@ -413,6 +417,8 @@ L<Sah> and L<Data::Sah>:
 
 =item * L<show-sah-schema-module>
 
+=item * L<show-sah-value-rule-modules>
+
 =item * L<validate-with-sah>
 
 =back
@@ -439,6 +445,8 @@ Arguments ('*' denotes required arguments):
 
 =item * B<schema>* => I<any>
 
+(No description)
+
 
 =back
 
@@ -474,6 +482,8 @@ Arguments ('*' denotes required arguments):
 
 =item * B<schema>* => I<any>
 
+(No description)
+
 
 =back
 
@@ -509,6 +519,8 @@ Arguments ('*' denotes required arguments):
 
 =item * B<schema>* => I<any>
 
+(No description)
+
 
 =back
 
@@ -545,6 +557,8 @@ Arguments ('*' denotes required arguments):
 
 =item * B<schema>* => I<any>
 
+(No description)
+
 
 =back
 
@@ -580,6 +594,8 @@ Arguments ('*' denotes required arguments):
 
 =item * B<schema>* => I<any>
 
+(No description)
+
 
 =back
 
@@ -616,6 +632,8 @@ Arguments ('*' denotes required arguments):
 
 =item * B<schema>* => I<any>
 
+(No description)
+
 
 =back
 
@@ -651,6 +669,8 @@ Arguments ('*' denotes required arguments):
 
 =item * B<schema>* => I<any>
 
+(No description)
+
 
 =back
 
@@ -687,6 +707,8 @@ Arguments ('*' denotes required arguments):
 
 =item * B<schema>* => I<any>
 
+(No description)
+
 
 =back
 
@@ -722,6 +744,8 @@ Arguments ('*' denotes required arguments):
 
 =item * B<schema>* => I<any>
 
+(No description)
+
 
 =back
 
@@ -758,6 +782,8 @@ Arguments ('*' denotes required arguments):
 
 =item * B<schema>* => I<any>
 
+(No description)
+
 
 =back
 
@@ -794,6 +820,8 @@ Arguments ('*' denotes required arguments):
 
 =item * B<schema>* => I<any>
 
+(No description)
+
 
 =back
 
@@ -844,7 +872,7 @@ that are considered a bug and can be reported to me.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2022, 2020, 2019, 2018, 2017, 2016, 2015 by perlancar <perlancar@cpan.org>.
+This software is copyright (c) 2023, 2022, 2020, 2019, 2018, 2017, 2016, 2015 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
